;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "khalel" "0.1.15"
  "Import, edit and create calendar events through khal."
  '((emacs "27.1"))
  :url "https://gitlab.com/hperrey/khalel"
  :commit "f7cdb3246d193a518b3a4ca7381ffb6ed8087fcf"
  :revdesc "f7cdb3246d19"
  :keywords '("event" "calendar" "ics" "khal")
  :authors '(("Hanno Perrey" . "http://gitlab.com/hperrey"))
  :maintainers '(("Hanno Perrey" . "hanno@hoowl.se")))
